@@ -181,12 +181,10 @@ extern bucket *errtoken;
 void output_token_defines();
 void output_token_const_def();
 void output_token_const_decl();
-void output_token_enum();
 extern int line_fparser;
 extern int line_fhskel;
 extern char *parser_fname;
 extern char *hskel_fname;
-extern char *version_string;
 
 
 
@@ -208,11 +206,10 @@ register YYLTYPE *yylsp;\n{\n  switch (n)\n{"
 void
 output_before_read()
 { 
-  fprintf(ftable, "\n/*  A Bison++ parser, made from %s  */\n\n", infile);
-  fprintf(ftable, " /* with Bison++ version %s  */\n\n", version_string);
+  fprintf(ftable, "\n/*  A Bison parser, made from %s  */\n\n", infile);
   output_section(fparser,ftable);
   if(definesflag) output_section(fhskel,fdefines);
-};
+}
 
 void
 output_headers()
@@ -392,8 +389,7 @@ output_gram()
   register int j;
   register short *sp;
 
-  /* With the ordinary parser,
-     yyprhs and yyrhs are needed only for yydebug.  */
+  /* With the ordinary parser, yyprhs is needed only for yydebug.  */
   if (!semantic_parser)
     fprintf(ftable, "\n#if YY_%s_DEBUG != 0",parser_name);
 
@@ -419,6 +415,9 @@ output_gram()
 
   fprintf(ftable, "\n};\n");
 
+  if(!semantic_parser)
+    fprintf(ftable, "\n#endif\n");
+
   fprintf(ftable, "\nstatic const short yyrhs[] = {%6d", ritem[0]);
 
   j = 10;
@@ -443,9 +442,6 @@ output_gram()
     }
 
   fprintf(ftable, "\n};\n");
-  if(!semantic_parser)
-    fprintf(ftable, "\n#endif\n");
-
 }
 
 
@@ -1401,9 +1397,9 @@ FILE *fin,*fout;
 	  {if (c == '$')
 	    {
   	    if (!nolinesflag)
-   		{//something is wrong                "\n/* #line %d \"%s\" */\n#line @\n",
-		  fprintf(fout, "\n #line %d \"%s\"\n", (*pcounter), quoted_filename(fil_name));
-                }
+   		fprintf(fout, 
+                "\n/* #line %d \"%s\" */\n",
+		 (*pcounter), quoted_filename(fil_name));
 	      return;
 	    }
            else if(c=='@')
@@ -1537,8 +1533,6 @@ void output_about_token()
   output_token_defines(ftable);
   output_section(fparser,ftable);
   output_token_const_decl(ftable);
-  output_section(fparser,ftable);  /* new section */
-  output_token_enum(ftable); /* enum */
   output_section(fparser,ftable);
   output_token_const_def(ftable);
   output_section(fparser,ftable);
@@ -1548,8 +1542,6 @@ void output_about_token()
       output_token_defines(fdefines);
       output_section(fhskel,fdefines);
       output_token_const_decl(fdefines);
-      output_section(fhskel,fdefines);  /* new section */
-      output_token_enum(fdefines); /* enum */
       output_section(fhskel,fdefines);
       if (semantic_parser)
 	for (i = ntokens; i < nsyms; i++)
@@ -1560,13 +1552,13 @@ void output_about_token()
 	  }
     }
 
-};
+}
 void output_token_defines(file)
 FILE *file;
 {output_token_defines_fmt(file,"#define\t%s\t%d\n",0);
  if (semantic_parser)
   output_token_defines_fmt(file,"#define\tT%s\t%d\n",1);
-};
+}
 void output_token_const_def(file)
 FILE *file;
 {char line[256];
@@ -1575,25 +1567,14 @@ FILE *file;
  sprintf(line,"const int YY_%s_CLASS::T%%s=%%d;\n",parser_name);
  if (semantic_parser)
   output_token_defines_fmt(file,line,1);
-};
+}
 void output_token_const_decl(file)
 FILE *file;
 {char line[256];
  output_token_defines_fmt(file,"static const int %s;\n",0);
  if (semantic_parser)
   output_token_defines_fmt(file,"static const int T%s;\n",1);
-};
-/* create a list like 
-	,FIRST_TOKEN=256
-	,SECOND_TOKEN=257
-*/
-void output_token_enum(file)
-FILE *file;
-{
- output_token_defines_fmt(file,"\t,%s=%d\n",0);
- if (semantic_parser) /* just for compatibility with semantic parser */
-  output_token_defines_fmt(file,"\t,T%s=%d\n",1);
-};
+}
 
 
 void
@@ -1640,7 +1621,7 @@ char *f;
  if(buff_size<strlen(f)*2+1)
   {
    if(buffer !=NULL ) free(buffer);
-   buffer=xmalloc(strlen(f)*2+1);
+   buffer=mallocate(strlen(f)*2+1);
   }
  for(p=buffer;*f;f++)
   {if(*f=='\\')
