@@ -48,7 +48,11 @@ extern int failure;
 extern int expected_conflicts;
 extern char *token_buffer;
 
+#ifndef _MSDOS
+extern char *realloc ();
+#endif
 
+extern int atoi ();
 
 extern void init_lex();
 extern void tabinit();
@@ -114,8 +118,6 @@ bucket *errtoken;
 /* Nonzero if any action or guard uses the @n construct.  */
 int yylsp_needed;
 
-extern char *version_string;
-
 extern void output_before_read();
 extern  void output_about_token();
 void set_parser_name();
@@ -306,7 +308,7 @@ copy_definition ()
  if (!nolinesflag)
     fprintf(ftable, "#line %d \"%s\"\n", lineno, quoted_filename(infile));
 
- copy_a_definition (cputc);
+ copy_a_definition (&cputc);
 }
 
 void
@@ -317,7 +319,7 @@ copy_header_definition ()
      if(definesflag) 
       fprintf(fdefines, "#line %d \"%s\"\n", lineno, quoted_filename(infile));
     }
- copy_a_definition (hputc);
+ copy_a_definition (&hputc);
 }
 void 
 hputc(c)
@@ -331,7 +333,7 @@ cputc(c)
 int c;
 {
  putc(c,ftable);
-};
+}
 
 void
 copy_a_definition (do_put)
@@ -1582,8 +1584,13 @@ record_rule_line ()
   if (nrules >= rline_allocated)
     {
       rline_allocated = nrules * 2;
-      rline = (short *) xrealloc (rline,
+      rline = (short *) realloc (rline,
 				 rline_allocated * sizeof (short));
+      if (rline == 0)
+	{
+	  fprintf (stderr, "%s: memory exhausted\n", program_name);
+	  done (1);
+	}
     }
   rline[nrules] = lineno;
 }
@@ -1818,7 +1825,7 @@ char *n;
       fatals("parser name already defined as \"%s\"and redefined to \"%s\"\n",parser_name,n);
     else
       parser_defined++;
-      parser_name=(char *)xmalloc(strlen(n)+1);
+      parser_name=(char *)mallocate(strlen(n)+1);
       strcpy(parser_name,n);
    }
  else /* use only */
@@ -1850,7 +1857,7 @@ int len;
      
  ungetc(c, finput);
 
-}  ;  
+}
 
 void
 parse_name_declaration()
